@@ -5,3 +5,5 @@ pub mod messagebox;
 pub mod nxui;
 pub mod window;
 pub mod windowclass;
+mod manifest;
+mod image;
