@@ -2,8 +2,9 @@ use crate::window::Window;
 
 pub fn run(window: Box<dyn Window>) {
     let attributes = window.attributes();
+    let manifest = window.manifest();
     window.startup();
     window.ui();
-    window.run(attributes);
+    window.run(attributes,manifest);
     window.exit();
 }
