@@ -10,11 +10,11 @@ use windows_sys::{
     Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect,
     Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*,
 };
+use crate::manifest::WindowManifest;
 
 #[cfg(windows)]
 #[derive(Clone)]
 pub struct WindowAttributes {
-    pub class: super::windowclass::WindowClass,
     pub style: WINDOW_STYLE,
     pub title: String,
     pub width: i32,
@@ -26,7 +26,6 @@ pub struct WindowAttributes {
 #[cfg(unix)]
 #[derive(Clone)]
 pub struct WindowAttributes {
-    pub class: super::windowclass::WindowClass,
     pub style: WindowType,
     pub title: String,
     pub width: i32,
@@ -38,7 +37,6 @@ pub struct WindowAttributes {
 #[cfg(windows)]
 impl WindowAttributes {
     pub fn new(
-        class: WindowClass,
         style: WINDOW_STYLE,
         title: String,
         width: i32,
@@ -47,7 +45,6 @@ impl WindowAttributes {
         y: i32,
     ) -> Self {
         Self {
-            class,
             style,
             title,
             width,
@@ -57,10 +54,6 @@ impl WindowAttributes {
         }
     }
 
-    pub fn get_class(self) -> WindowClass {
-        self.class
-    }
-
     pub fn get_style(self) -> WINDOW_STYLE {
         self.style
     }
@@ -140,13 +133,14 @@ impl WindowAttributes {
 #[cfg(windows)]
 pub trait Window {
     fn attributes(&self) -> WindowAttributes;
+    fn manifest(&self) -> WindowManifest;
     fn startup(&self) {
         println!("Startup Phase")
     }
     fn ui(&self) {
         println!("UI Phase")
     }
-    fn run(&self, attributes: WindowAttributes) {
+    fn run(&self, attributes: WindowAttributes,manifest: WindowManifest) {
         println!("Run Phase");
         let window: HWND;
         extern "system" fn wndproc(
@@ -177,7 +171,7 @@ pub trait Window {
             let wc = WNDCLASSA {
                 hCursor: LoadCursorW(0, IDC_ARROW),
                 hInstance: instance,
-                lpszClassName: attributes.clone().class.get_class(),
+                lpszClassName: manifest.class,
                 style: CS_HREDRAW | CS_VREDRAW,
                 lpfnWndProc: Some(wndproc),
                 cbClsExtra: 0,
@@ -192,7 +186,7 @@ pub trait Window {
 
             CreateWindowExA(
                 0,
-                attributes.class.get_class(),
+                manifest.class,
                 attributes.title.as_ptr() as _,
                 WS_VISIBLE | attributes.style,
                 CW_USEDEFAULT,
@@ -228,7 +222,11 @@ pub trait Window {
     }
     fn run(&self, attributes: WindowAttributes) {
         use gtk::prelude::*;
-        let window = gtk::ApplicationWindow::new(attributes.clone().style);
+        let application = gtk::Application::new(
+            Some(&*attributes.clone().class.get_application_id()),
+            Default::default(),
+        );
+        let window = gtk::ApplicationWindow::new(&application);
 
         window.set_title(&*attributes.clone().title);
         window.set_border_width(10);
@@ -237,11 +235,6 @@ pub trait Window {
 
         window.show_all();
 
-        let application = gtk::Application::new(
-            Some(&*attributes.clone().class.get_application_id()),
-            Default::default(),
-        );
-
         application.run();
     }
     fn exit(&self) {
